@@ -5,11 +5,12 @@ Library used to provide the appropriate data dir for virt test.
 import inspect
 import logging
 import os
-import sys
 import glob
 import shutil
 import stat
 
+import pkg_resources
+
 from avocado.core import data_dir
 from avocado.utils import distro
 from avocado.utils import path as utils_path
@@ -18,28 +19,14 @@ from virttest.compat import get_settings_value
 
 from six.moves import xrange
 
-if hasattr(sys, 'real_prefix'):
-    # unlike default execution venv prefix does not contain /usr
-    _DEFAULT_SHARED_PATH = os.path.join(sys.prefix, "shared")
-else:
-    _DEFAULT_SHARED_PATH = os.path.join(sys.prefix, "share",
-                                        "avocado-plugins-vt",
-                                        "shared")
-
-if (os.path.isdir(_DEFAULT_SHARED_PATH) and
-        len(os.listdir(_DEFAULT_SHARED_PATH)) > 0):
-    _ROOT_PATH = os.path.dirname(_DEFAULT_SHARED_PATH)
-else:
-    _ROOT_PATH = os.path.realpath(os.path.dirname(os.path.dirname(__file__)))
-
-ROOT_DIR = os.path.abspath(_ROOT_PATH)
-BASE_BACKEND_DIR = os.path.join(ROOT_DIR, 'backends')
-DATA_DIR = os.path.join(data_dir.get_data_dir(), 'avocado-vt')
-SHARED_DIR = os.path.join(ROOT_DIR, 'shared')
-DEPS_DIR = os.path.join(ROOT_DIR, 'shared', 'deps')
+BASE_BACKEND_DIR = pkg_resources.resource_filename('virttest', 'backends')
+TEST_PROVIDERS_DIR = pkg_resources.resource_filename('virttest', 'test-providers.d')
+SHARED_DIR = pkg_resources.resource_filename('virttest', 'shared')
+DEPS_DIR = os.path.join(SHARED_DIR, 'deps')
 BASE_DOWNLOAD_DIR = os.path.join(SHARED_DIR, 'downloads')
+
+DATA_DIR = os.path.join(data_dir.get_data_dir(), 'avocado-vt')
 DOWNLOAD_DIR = os.path.join(DATA_DIR, 'downloads')
-TEST_PROVIDERS_DIR = os.path.join(ROOT_DIR, 'test-providers.d')
 BACKING_DATA_DIR = None
 
 
@@ -128,7 +115,7 @@ BACKING_DATA_DIR = get_backing_data_dir()
 
 
 def get_root_dir():
-    return ROOT_DIR
+    return os.path.dirname(BASE_BACKEND_DIR)
 
 
 def get_data_dir():
@@ -239,7 +226,9 @@ def get_download_dir():
     return DOWNLOAD_DIR
 
 
-TEST_PROVIDERS_DOWNLOAD_DIR = os.path.join(get_data_dir(), 'test-providers.d',
+TEST_PROVIDERS_DOWNLOAD_DIR = os.path.join(get_data_dir(),
+                                           'virttest',
+                                           'test-providers.d',
                                            'downloads')
 
 
@@ -271,7 +260,7 @@ def clean_tmp_files():
 
 
 if __name__ == '__main__':
-    print("root dir:         " + ROOT_DIR)
+    print("root dir:         " + get_root_dir())
     print("tmp dir:          " + get_tmp_dir())
     print("data dir:         " + DATA_DIR)
     print("deps dir:         " + DEPS_DIR)
