@@ -10,7 +10,7 @@ from virttest.libvirt_xml.devices import base
 
 class Memballoon(base.UntypedDeviceBase):
 
-    __slots__ = ('model', 'stats_period', 'address')
+    __slots__ = ('model', 'stats_period', 'address', 'driver_packed')
 
     def __init__(self, virsh_instance=base.base.virsh):
         accessors.XMLAttribute('model', self, parent_xpath='/',
@@ -19,5 +19,7 @@ class Memballoon(base.UntypedDeviceBase):
                                tag_name='stats', attribute='period')
         accessors.XMLElementDict('address', self, parent_xpath='/',
                                  tag_name='address')
+        accessors.XMLAttribute('driver_packed', self, parent_xpath='/',
+                               tag_name='driver', attribute='packed')
         super(Memballoon, self).__init__(device_tag='memballoon',
                                          virsh_instance=virsh_instance)
