@@ -1,11 +1,13 @@
 import os
 import logging
+
 import aexpect
+from aexpect import remote
 
 from avocado.utils import process
 from avocado.utils import path
 
-from virttest import remote
+from virttest import remote as remote_old
 
 
 def get_public_key():
@@ -217,7 +219,7 @@ def setup_remote_known_hosts_file(client_ip, server_ip,
     :type server_pwd: str
 
     :return: a RemoteFile object for the file known_hosts on remote host
-    :rtype: remote.RemoteFile
+    :rtype: remote_old.RemoteFile
     :return: None if required command is not found
     """
     logging.debug('Performing known_hosts file setup on %s from %s.' %
@@ -231,7 +233,7 @@ def setup_remote_known_hosts_file(client_ip, server_ip,
 
     cmd = "%s %s" % (abs_path, client_ip)
     host_key = process.run(cmd, verbose=False).stdout_text
-    remote_known_hosts_file = remote.RemoteFile(
+    remote_known_hosts_file = remote_old.RemoteFile(
         address=server_ip,
         client='scp',
         username=server_user,
