@@ -7,6 +7,7 @@ import os
 import glob
 import shutil
 import stat
+import platform
 import random
 import string
 import tempfile
@@ -20,6 +21,7 @@ from functools import cmp_to_key
 
 from avocado.core import exceptions
 from avocado.utils import process
+from avocado.utils import wait
 from avocado.utils.service import SpecificServiceManager
 
 from virttest import error_context
@@ -204,30 +206,32 @@ def get_linux_disks(session, partition=False):
     :return: the disks dict.
              e.g. {kname: [kname, size, type, serial, wwn]}
     """
-    list_disk_cmd = "lsblk -o KNAME,SIZE,TYPE,SERIAL,WWN"
-    get_disk_name_cmd = "lsblk -no pkname /dev/%s"
-    output = session.cmd_output(list_disk_cmd)
-    devs = output.splitlines()
     disks_dict = {}
-    part_dict = {}
-    for dev in devs:
-        dev = dev.split()
-        if "disk" in dev:
-            disks_dict[dev[0]] = dev
-        if "part" in dev:
-            part_dict[dev[0]] = dev
-    if partition:
-        disks_dict = dict(disks_dict, **part_dict)
-    else:
-        for part in part_dict.keys():
-            output = session.cmd_output(get_disk_name_cmd % part)
-            disk = output.splitlines()[0].strip()
-            if disk in disks_dict.keys():
-                disks_dict.pop(disk)
+    parent_disks = set()
+    driver = "pci"
+    if platform.machine() == "s390x":
+        driver = "css0"
+    block_info = session.cmd('ls /sys/dev/block -l | grep "/%s"' % driver)
+    for matched in re.finditer(r'/block/(\S+)\s^', block_info, re.M):
+        knames = matched.group(1).split('/')
+        if len(knames) == 2:
+            parent_disks.add(knames[0])
+        if partition is False and knames[0] in parent_disks:
+            if knames[0] in disks_dict:
+                del disks_dict[knames[0]]
+            continue
+
+        disks_dict[knames[-1]] = [knames[-1]]
+        o = session.cmd('lsblk -o KNAME,SIZE | grep "%s "' % knames[-1])
+        disks_dict[knames[-1]].append(o.split()[-1])
+        o = session.cmd('udevadm info -q all -n %s' % knames[-1])
+        for parttern in (r'DEVTYPE=(\w+)\s^', r'ID_SERIAL=(\S+)\s^', r'ID_WWN=(\S+)\s^'):
+            searched = re.search(parttern, o, re.M | re.I)
+            disks_dict[knames[-1]].append(searched.group(1) if searched else None)
     return disks_dict
 
 
-def get_windows_disks_index(session, image_size):
+def get_windows_disks_index(session, image_size, timeout=60):
     """
     Get all disks index which show in 'diskpart list disk'.
     except for system disk.
@@ -236,6 +240,7 @@ def get_windows_disks_index(session, image_size):
 
     :param session: session object to guest.
     :param image_size: image size. e.g. 40M
+    :param timeout: timeout for getting disks index.
     :return: a list with all disks index except for system disk.
     """
     disk = "disk_" + ''.join(random.sample(string.ascii_letters + string.digits, 4))
@@ -244,7 +249,7 @@ def get_windows_disks_index(session, image_size):
     list_disk_cmd += " && echo exit >> " + disk
     list_disk_cmd += " && diskpart /s " + disk
     list_disk_cmd += " && del /f " + disk
-    disks = session.cmd_output(list_disk_cmd)
+    disks = session.cmd_output(list_disk_cmd, timeout)
     size_type = image_size[-1] + "B"
     if size_type == "MB":
         disk_size = image_size[:-1] + " MB"
@@ -375,15 +380,31 @@ def create_partition_linux(session, did, size, start,
     :param start: partition beginning at start. e.g. 0M
     :param part_type: partition type, primary extended logical
     :param timeout: Timeout for cmd execution in seconds.
+    :return: The kname of partition created.
     """
+    def _list_disk_partitions():
+        driver = "pci"
+        if platform.machine() == "s390x":
+            driver = "css0"
+        o = session.cmd('ls /sys/dev/block -l | grep "/%s" | grep "%s"' %
+                        (driver, did))
+        return set(o.splitlines())
+
     size = utils_numeric.normalize_data_size(size, order_magnitude="M") + "M"
     start = utils_numeric.normalize_data_size(start, order_magnitude="M") + "M"
     end = str(float(start[:-1]) + float(size[:-1])) + size[-1]
+    orig_disks = _list_disk_partitions()
     partprobe_cmd = "partprobe /dev/%s" % did
     mkpart_cmd = 'parted -s "%s" mkpart %s %s %s'
     mkpart_cmd %= ("/dev/%s" % did, part_type, start, end)
     session.cmd(mkpart_cmd)
     session.cmd(partprobe_cmd, timeout=timeout)
+    partition_created = wait.wait_for(lambda: _list_disk_partitions() - orig_disks,
+                                      step=0.5, timeout=30)
+    if not partition_created:
+        raise exceptions.TestError('Failed to create partition.')
+    kname = partition_created.pop().split('/')[-1]
+    return kname
 
 
 def create_partition_windows(session, did, size, start,
@@ -397,13 +418,15 @@ def create_partition_windows(session, did, size, start,
     :param start: partition beginning at start. e.g. 0M
     :param part_type: partition type, primary extended logical
     :param timeout: Timeout for cmd execution in seconds.
+    :return: The index of partition created.
     """
     size = utils_numeric.normalize_data_size(size, order_magnitude="M")
     start = utils_numeric.normalize_data_size(start, order_magnitude="M")
     size = int(float(size) - float(start))
-    mkpart_cmd = " echo create partition %s size=%s"
+    mkpart_cmd = " echo create partition %s size=%s; echo list partition"
     mkpart_cmd = _wrap_windows_cmd(mkpart_cmd)
-    session.cmd(mkpart_cmd % (did, part_type, size), timeout=timeout)
+    output = session.cmd(mkpart_cmd % (did, part_type, size), timeout=timeout)
+    return re.search(r'\*\s+Partition\s+(\d+)\s+', output, re.M).group(1)
 
 
 def create_partition(session, did, size, start, ostype,
@@ -418,11 +441,12 @@ def create_partition(session, did, size, start, ostype,
     :param ostype: linux or windows.
     :param part_type: partition type, primary extended logical
     :param timeout: Timeout for cmd execution in seconds.
+    :return: The kname of partition created in linux, index in windows.
     """
     if ostype == "windows":
-        create_partition_windows(session, did, size, start, part_type, timeout)
+        return create_partition_windows(session, did, size, start, part_type, timeout)
     else:
-        create_partition_linux(session, did, size, start, part_type, timeout)
+        return create_partition_linux(session, did, size, start, part_type, timeout)
 
 
 def delete_partition_linux(session, partition_name, timeout=360):
@@ -433,8 +457,12 @@ def delete_partition_linux(session, partition_name, timeout=360):
     :param partition_name: partition name. e.g. sdb1
     :param timeout: Timeout for cmd execution in seconds.
     """
-    get_kname_cmd = "lsblk -no pkname /dev/%s"
-    kname = session.cmd_output(get_kname_cmd % partition_name)
+    driver = "pci"
+    if platform.machine() == "s390x":
+        driver = "css0"
+    ls_block_cmd = 'ls /sys/dev/block -l | grep "/%s"' % driver
+    regex = r'/block/(\S+)/%s\s^' % partition_name
+    kname = re.search(regex, session.cmd(ls_block_cmd), re.M).group(1)
     list_disk_cmd = "lsblk -o KNAME,MOUNTPOINT"
     output = session.cmd_output(list_disk_cmd)
     output = output.splitlines()
@@ -449,6 +477,9 @@ def delete_partition_linux(session, partition_name, timeout=360):
             break
     session.cmd(rm_cmd % (kname, partition[0]))
     session.cmd("partprobe /dev/%s" % kname, timeout=timeout)
+    if not wait.wait_for(lambda: not re.search(
+            regex, session.cmd(ls_block_cmd), re.M), step=0.5, timeout=30):
+        raise exceptions.TestError('Failed to delete partition.')
 
 
 def delete_partition_windows(session, partition_name, timeout=360):
@@ -515,6 +546,15 @@ def clean_partition_linux(session, did, timeout=360):
             logging.info("remove partition %s on %s" % (number, did))
             session.cmd(rm_cmd % (did, number))
         session.cmd("partprobe /dev/%s" % did, timeout=timeout)
+        regex = r'/block/%s/\S+\s^' % did
+        driver = "pci"
+        if platform.machine() == "s390x":
+            driver = "css0"
+        ls_block_cmd = ('ls /sys/dev/block -l | grep "/%s" | grep "%s"' %
+                        (driver, did))
+        if not wait.wait_for(lambda: not re.search(
+                regex, session.cmd(ls_block_cmd), re.M), step=0.5, timeout=30):
+            raise exceptions.TestError('Failed to clean the all partitions.')
 
 
 def clean_partition_windows(session, did, timeout=360):
@@ -822,13 +862,14 @@ def get_drive_letters(session, did):
     return []
 
 
-def set_drive_letter(session, did, partition_no=1):
+def set_drive_letter(session, did, partition_no=1, target_letter=None):
     """
     set drive letter for partition in windows guest.
 
     :param session: session object to guest.
     :param did: disk index
     :param partition_no: partition number
+    :param target_letter: target drive letter
     :return drive_letter: drive letter has been set
     """
     drive_letter = ""
@@ -839,6 +880,8 @@ def set_drive_letter(session, did, partition_no=1):
         if re.search("Reserved", line, re.I | re.M):
             partition_no += int(line.split()[1])
     assign_letter_cmd = ' echo select partition %s ; echo assign '
+    if target_letter:
+        assign_letter_cmd += 'letter=%s' % target_letter
     assign_letter_cmd = _wrap_windows_cmd(assign_letter_cmd)
     session.cmd(assign_letter_cmd % (did, partition_no))
     detail_cmd = ' echo detail disk '
@@ -850,6 +893,9 @@ def set_drive_letter(session, did, partition_no=1):
             drive_letter = line.split()[2]
             break
     if len(drive_letter) == 1 and drive_letter.isalpha():
+        if target_letter:
+            if target_letter != drive_letter:
+                return None
         return drive_letter
     else:
         return None
@@ -953,24 +999,23 @@ def configure_empty_linux_disk(session, did, size, start="0M", n_partitions=1,
     else:
         part_type = PARTITION_TYPE_PRIMARY
     for i in range(n_partitions):
-        pre_partition = get_linux_disks(session, partition=True).keys()
         if i == 0:
-            create_partition_linux(session, did, str(partition_size) + size[-1],
-                                   str(start) + size[-1], timeout=timeout)
+            new_partition = create_partition_linux(
+                    session, did, str(partition_size) + size[-1],
+                    str(start) + size[-1], timeout=timeout)
         else:
             if part_type == PARTITION_TYPE_EXTENDED:
                 create_partition_linux(session, did, str(extended_size) + size[-1],
                                        str(start) + size[-1], part_type, timeout)
-                pre_partition = get_linux_disks(session, partition=True).keys()
                 part_type = PARTITION_TYPE_LOGICAL
-                create_partition_linux(session, did, str(partition_size) + size[-1],
-                                       str(start) + size[-1], part_type, timeout)
+                new_partition = create_partition_linux(
+                        session, did, str(partition_size) + size[-1],
+                        str(start) + size[-1], part_type, timeout)
             else:
-                create_partition_linux(session, did, str(partition_size) + size[-1],
-                                       str(start) + size[-1], part_type, timeout)
+                new_partition = create_partition_linux(
+                        session, did, str(partition_size) + size[-1],
+                        str(start) + size[-1], part_type, timeout)
         start += partition_size
-        post_partition = get_linux_disks(session, partition=True).keys()
-        new_partition = list(set(post_partition) - set(pre_partition))[0]
         create_filesyetem_linux(session, new_partition, fstype, timeout)
         mount_dst = "/mnt/" + new_partition
         session.cmd("rm -rf %s; mkdir %s" % (mount_dst, mount_dst))
