@@ -1304,8 +1304,17 @@ def v2v_cmd(params, auto_clean=True, cmd_only=False, interaction=False):
             for i in range(int(params.get('_disk_count', 0))):
                 options += ' -oo rhv-disk-uuid=%s' % str(uuid.uuid4())
 
+        # Protect the blanks in original guest name
+        safe_vm_name = ''
+        BLANK_REPLACEMENT = '%20'
+        if ' ' in vm_name and vm_name in options:
+            safe_vm_name = vm_name.replace(' ', BLANK_REPLACEMENT)
+            options = options.replace(vm_name, safe_vm_name)
         # Construct a final virt-v2v command and remove redundant blanks
         cmd = ' '.join(('%s %s' % (V2V_EXEC, options)).split())
+        # Restore the real original guest name
+        if safe_vm_name:
+            cmd = cmd.replace(safe_vm_name, vm_name)
         # Old v2v version doesn't support '-ip' option
         if not v2v_supported_option("-ip <filename>"):
             cmd = cmd.replace('-ip', '--password-file', 1)
@@ -1792,7 +1801,7 @@ def get_esx_disk_source_info(vm_name, virsh_instance):
     :param v2v_virsh_instance: a virsh instance
     """
     def _parse_file_info(path):
-        res = re.search(r'\[(.*)\] (.*?)/(.*\.vmdk)', path)
+        res = re.search(r'\[(.*)\] (.*)/(.*\.vmdk)', path)
         if not res:
             return []
         return [res.group(i) for i in range(1, 4)]
@@ -1896,8 +1905,10 @@ def compare_version(interval, version=None, cmd=None):
     if not version:
         if not cmd:
             cmd = 'rpm -q virt-v2v'
-        # exit status checking will be done in process.run
-        version = process.run(cmd, shell=True).stdout_text.strip()
+        res = process.run(cmd, shell=True, ignore_status=True)
+        if res.exit_status != 0:
+            return False
+        version = res.stdout_text.strip()
 
     return check_version(version, interval)
 
